@@ -48,6 +48,8 @@ static const R_CallMethodDef callMethods[]  = {
     (DL_FUNC) &processx_connection_disable_inheritance, 0 },
 
   { "processx_disable_crash_dialog",  (DL_FUNC) &processx_disable_crash_dialog,   0 },
+  { "processx_base64_encode", (DL_FUNC) &processx_base64_encode, 1 },
+  { "processx_base64_decode", (DL_FUNC) &processx_base64_decode, 1 },
 
   { NULL, NULL, 0 }
 };
