@@ -63,6 +63,9 @@ SEXP processx_write_named_pipe(SEXP pipe_ext, SEXP text);
 
 SEXP processx_disable_crash_dialog();
 
+SEXP processx_base64_encode(SEXP array);
+SEXP processx_base64_decode(SEXP array);
+
 /* Common declarations */
 
 /* Interruption interval in ms */
